from setuptools import setup

setup(
	name='zaider',
	version='0.0.1',
	description='Zaider Technologies packages',
	packages=['zaider'],
	package_dir={'':'src'},

	author='Costin Leonte',
	author_email='costin.leonte@gmail.com',
	url='https://github.com/costin-leonte/zaider'
)